@@ -1,13 +1,13 @@
 #' NNS Partition Map
 #'
-#' Creates partitions based on partial moment quadrant means, iteratively assigning identifications to observations based on those quadrants (unsupervised partitional and hierarchial clustering method).  Basis for correlation \link{NNS.cor}, dependence \link{NNS.dep}, regression \link{NNS.reg} routines.
+#' Creates partitions based on partial moment quadrant means, iteratively assigning identifications to observations based on those quadrants (unsupervised partitional and hierarchial clustering method).  Basis for correlation, dependence \link{NNS.dep}, regression \link{NNS.reg} routines.
 #'
 #' @param x a numeric vector.
 #' @param y a numeric vector with compatible dimensions to \code{x}.
 #' @param Voronoi logical; \code{FALSE} (default) Displays a Voronoi type diagram using partial moment quadrants.
 #' @param type \code{NULL} (default) Controls the partitioning basis.  Set to \code{(type = "XONLY")} for X-axis based partitioning.  Defaults to \code{NULL} for both X and Y-axis partitioning.
 #' @param order integer; Number of partial moment quadrants to be generated.  \code{(order = "max")} will institute a perfect fit.
-#' @param obs.req integer; (10 default) Required observations per cluster where quadrants will not be further partitioned if observations are not greater than the entered value.  Reduces minimum number of necessary observations in a quadrant to 1 when \code{(obs.req = 1)}.
+#' @param obs.req integer; (8 default) Required observations per cluster where quadrants will not be further partitioned if observations are not greater than the entered value.  Reduces minimum number of necessary observations in a quadrant to 1 when \code{(obs.req = 1)}.
 #' @param min.obs.stop logical; \code{TRUE} (default) Stopping condition where quadrants will not be further partitioned if a single cluster contains less than the entered value of \code{obs.req}.
 #' @param noise.reduction the method of determining regression points options: ("mean", "median", "mode", "off"); \code{(noise.reduction = "mean")} uses means for partitions.  \code{(noise.reduction = "median")} uses medians instead of means for partitions, while \code{(noise.reduction = "mode")} uses modes instead of means for partitions.  Defaults to \code{(noise.reduction = "off")} where an overall central tendency measure is used.
 #' @return Returns:
@@ -44,7 +44,7 @@ NNS.part = function(x, y,
                     Voronoi = FALSE,
                     type = NULL,
                     order = NULL,
-                    obs.req = 10,
+                    obs.req = 8,
                     min.obs.stop = TRUE,
                     noise.reduction = "off"){
 
@@ -73,7 +73,7 @@ NNS.part = function(x, y,
     x <- as.numeric(x)
     y <- as.numeric(y)
 
-    if (length(x) < 8) {
+    if (length(x) <= 8) {
         order <- 1
         obs.req <- 0
     }
@@ -256,12 +256,12 @@ NNS.part = function(x, y,
         i <- 0L
         while (i >= 0) {
             if(i == order || i == hard.stop) break
-            PART[counts >= obs.req, `:=`(counts, .N), by = quadrant]
-            PART[old.counts >= obs.req, `:=`(old.counts, .N), by = prior.quadrant]
+            PART[counts > obs.req/2, `:=`(counts, .N), by = quadrant]
+            PART[old.counts > obs.req/2, `:=`(old.counts, .N), by = prior.quadrant]
 
-            obs.req.rows <- PART[counts >= obs.req, which = TRUE]
+            obs.req.rows <- PART[counts > obs.req/2, which = TRUE]
 
-            old.obs.req.rows <- PART[old.counts >= obs.req, which = TRUE]
+            old.obs.req.rows <- PART[old.counts > obs.req/2, which = TRUE]
 
             if(obs.req > 0 && (length(obs.req.rows) < length(old.obs.req.rows))) break
             if(noise.reduction == "off") {
